@@ -1,10 +1,10 @@
-#!/usr/bin/env python2
+#!/usr/bin/env python3
 ##
 #     Project: gWakeOnLAN
 # Description: Wake up your machines using Wake on LAN
-#      Author: Fabio Castelli (Muflone) <muflone@vbsimple.net>
-#   Copyright: 2009-2014 Fabio Castelli
-#     License: GPL-2+
+#      Author: Fabio Castelli (Muflone) <muflone@muflone.com>
+#   Copyright: 2009-2020 Fabio Castelli
+#     License: GPL-3+
 #  This program is free software; you can redistribute it and/or modify it
 #  under the terms of the GNU General Public License as published by the Free
 #  Software Foundation; either version 2 of the License, or (at your option)
@@ -21,20 +21,25 @@
 
 import gettext
 import locale
-from gwakeonlan.settings import Settings
-from gwakeonlan.app import Application
-from gwakeonlan.constants import *
+
+import gi
+gi.require_version('Gtk', '3.0')
+
+from gwakeonlan.app import Application                             # noqa: E402
+from gwakeonlan.constants import DIR_LOCALE, DOMAIN_NAME           # noqa: E402
+from gwakeonlan.settings import Settings                           # noqa: E402
+
 
 if __name__ == '__main__':
-  # Load domain for translation
-  for module in (gettext, locale):
-    module.bindtextdomain(DOMAIN_NAME, DIR_LOCALE)
-    module.textdomain(DOMAIN_NAME)
+    # Load domain for translation
+    for module in (gettext, locale):
+        module.bindtextdomain(DOMAIN_NAME, DIR_LOCALE)
+        module.textdomain(DOMAIN_NAME)
 
-  # Load the settings from the configuration file
-  settings = Settings()
-  settings.load()
+    # Load the settings from the configuration file
+    settings = Settings()
+    settings.load()
 
-  # Start the application
-  app = Application(settings)
-  app.run(None)
+    # Start the application
+    app = Application(settings)
+    app.run(None)
